@@ -1,3 +1,6 @@
+import asyncio
+from PySide6.QtCore import QCoreApplication
+from PySide6.QtCore import Qt
 import nest_asyncio
 from AgentCrew.modules.config import ConfigManagement
 import click
@@ -47,7 +50,6 @@ def cli_prod():
     os.environ["PERSISTENCE_DIR"] = os.path.expanduser("~/.AgentCrew/persistents")
     os.environ["AGENTCREW_CONFIG_PATH"] = os.path.expanduser("~/.AgentCrew/config.json")
 
-    check_and_update()
     cli()  # Delegate to main CLI function
 
 
@@ -106,6 +108,7 @@ def check_and_update():
         # Get current version from __version__ or a version file
         current_version = get_current_version()
 
+        click.echo(f"Current version: {current_version}\nChecking for updates...")
         # Get latest version from GitHub API
         latest_version = get_latest_github_version()
 
@@ -113,7 +116,6 @@ def check_and_update():
             click.echo("⚠️ Could not determine version information", err=True)
             return
 
-        click.echo(f"Current version: {current_version}")
         click.echo(f"Latest version: {latest_version}")
 
         if version_is_older(current_version, latest_version):
@@ -223,16 +225,12 @@ def run_update_command():
 
         if system == "linux" or system == "darwin":  # Darwin is macOS
             # Linux/macOS update command
-            command = (
-                "uv tool install --reinstall --force --python=3.12 agentcrew-ai@latest"
-            )
+            command = "uv tool install --python=3.12 --force agentcrew-ai[cpu] --index https://download.pytorch.org/whl/cpu --index-strategy unsafe-best-match"
             click.echo("🐧 Running Linux/macOS update command...")
 
         elif system == "windows":
             # Windows update command
-            command = (
-                "uv tool install --reinstall --force --python=3.12 agentcrew-ai@latest"
-            )
+            command = "uv tool install --python=3.12 --force agentcrew-ai[cpu] --index https://download.pytorch.org/whl/cpu --index-strategy unsafe-best-match"
             click.echo("🪟 Running Windows update command...")
 
         else:
@@ -544,6 +542,7 @@ def discover_and_register_tools(services=None):
 )
 def chat(provider, agent_config, mcp_config, memory_llm, console):
     """Start an interactive chat session with LLM"""
+    check_and_update()
     try:
         load_api_keys_from_config()
 
@@ -630,6 +629,7 @@ def chat(provider, agent_config, mcp_config, memory_llm, console):
 
         # Choose between GUI and console based on the --gui flag
         if not console:
+            QCoreApplication.setAttribute(Qt.ApplicationAttribute.AA_UseOpenGLES)
             app = QApplication(sys.argv)
             chat_window = ChatWindow(message_handler)
             chat_window.show()
@@ -741,6 +741,104 @@ def a2a_server(
         MCPSessionManager.get_instance().cleanup()
 
 
+@cli.command()
+@click.option("--agent", type=str, help="Name of the agent to run")
+@click.option(
+    "--provider",
+    type=click.Choice(
+        ["claude", "groq", "openai", "google", "github_copilot", "deepinfra"]
+    ),
+    default=None,
+    help="LLM provider to use (claude, groq, openai, google, github_copilot or deepinfra)",
+)
+@click.option("--model-id", default=None, help="Model ID from provider")
+@click.option("--agent-config", default=None, help="Path to agent configuration file")
+@click.option(
+    "--mcp-config", default=None, help="Path to the mcp servers configuration file."
+)
+@click.option(
+    "--memory-llm",
+    type=click.Choice(["claude", "groq", "openai", "google"]),
+    default=None,
+    help="LLM Model use for analyzing and processing memory",
+)
+@click.argument(
+    "task",
+    nargs=1,
+    type=str,
+)
+@click.argument(
+    "files",
+    nargs=-1,
+    type=click.Path(),
+)
+def job(agent, provider, model_id, agent_config, mcp_config, memory_llm, task, files):
+    try:
+        load_api_keys_from_config()
+
+        if provider is None:
+            if os.getenv("GITHUB_COPILOT_API_KEY"):
+                provider = "github_copilot"
+            elif os.getenv("ANTHROPIC_API_KEY"):
+                provider = "claude"
+            elif os.getenv("GEMINI_API_KEY"):
+                provider = "google"
+            elif os.getenv("OPENAI_API_KEY"):
+                provider = "openai"
+            elif os.getenv("GROQ_API_KEY"):
+                provider = "groq"
+            elif os.getenv("DEEPINFRA_API_KEY"):
+                provider = "deepinfra"
+            else:
+                raise ValueError(
+                    "No LLM API key found. Please set either ANTHROPIC_API_KEY, GEMINI_API_KEY, OPENAI_API_KEY, GROQ_API_KEY, or DEEPINFRA_API_KEY"
+                )
+
+        services = setup_services(provider, memory_llm)
+        if mcp_config:
+            os.environ["MCP_CONFIG_PATH"] = mcp_config
+        #
+        # Set up agents from configuration
+        setup_agents(services, agent_config)
+
+        message_handler = MessageHandler(
+            services["memory"], services["context_persistent"]
+        )
+        message_handler.is_non_interactive = True
+        # # Get agent manager
+        agent_manager = message_handler.agent_manager
+        llm_manager = ServiceManager.get_instance()
+
+        llm_service = llm_manager.get_service(provider)
+        if model_id:
+            llm_service.model = model_id
+
+        agent_manager.update_llm_service(llm_service)
+
+        for local_agent in agent_manager.agents:
+            if isinstance(local_agent, LocalAgent):
+                local_agent.is_remoting_mode = True
+
+        agent_manager.enforce_transfer = False
+        agent_manager.one_turn_process = True
+        if agent_manager.select_agent(agent):
+            message_handler.agent = agent_manager.get_current_agent()
+            for file_path in files:
+                asyncio.run(message_handler.process_user_input(f"/file {file_path}"))
+            asyncio.run(message_handler.process_user_input(task))
+            response, _, _ = asyncio.run(message_handler.get_assistant_response())
+            click.echo(response)
+
+            from AgentCrew.modules.mcpclient import MCPSessionManager
+
+            MCPSessionManager.get_instance().cleanup()
+            sys.exit(0)
+            # message_handler.process_user_input()
+    except Exception as e:
+        print(traceback.format_exc())
+        click.echo(f"❌ Error: {str(e)}", err=True)
+
+
 @cli.command()
 def copilot_auth():
     """Authenticate with GitHub Copilot and save the API key to config"""
