@@ -27,7 +27,6 @@ class AnthropicService(BaseLLMService):
         self.thinking_budget = 0
         self.caching_blocks = 0
         self._provider_name = "claude"
-        self.temperature = 0.4
         self.system_prompt = ""
         logger.info("Initialized Anthropic Service")
 
@@ -166,7 +165,7 @@ class AnthropicService(BaseLLMService):
             dict: Result of the tool execution
         """
         if tool_name not in self.tool_handlers:
-            return {"error": f"Tool '{tool_name}' not found"}
+            raise ValueError(f"Tool '{tool_name}' not found")
 
         handler = self.tool_handlers[tool_name]
         result = handler(**tool_params)
