@@ -11,7 +11,6 @@ from AgentCrew.modules.agents import AgentManager
 from AgentCrew.modules.chat.file_handler import FileHandler
 from AgentCrew.modules.llm.message import MessageTransformer
 from AgentCrew.modules.config import ConfigManagement
-from AgentCrew.modules.voice import DeepInfraVoiceService, ElevenLabsVoiceService
 from AgentCrew.modules.memory import (
     BaseMemoryService,
     ContextPersistenceService,
@@ -61,6 +60,7 @@ class MessageHandler(Observable):
         self._queued_attached_files = []
         self.stop_streaming = False
         self.streamline_messages = []
+        self.is_non_interactive = False
         self.current_conversation_id: Optional[str] = None  # ID for persistence
 
         # Initialize components
@@ -73,10 +73,18 @@ class MessageHandler(Observable):
         # Voice integration
         self.voice_service = None
         # Check if voice service is available
-        if os.getenv("ELEVENLABS_API_KEY"):
-            self.voice_service = ElevenLabsVoiceService()
-        elif os.getenv("DEEPINFRA_API_KEY"):
-            self.voice_service = DeepInfraVoiceService()
+        from AgentCrew.modules.voice import AUDIO_AVAILABLE
+
+        if AUDIO_AVAILABLE:
+            from AgentCrew.modules.voice import (
+                DeepInfraVoiceService,
+                ElevenLabsVoiceService,
+            )
+
+            if os.getenv("ELEVENLABS_API_KEY"):
+                self.voice_service = ElevenLabsVoiceService()
+            elif os.getenv("DEEPINFRA_API_KEY"):
+                self.voice_service = DeepInfraVoiceService()
 
     def _messages_append(self, message):
         """Append a message to the agent history and streamline messages."""
