@@ -70,7 +70,11 @@ class ToolManager:
                 )
             return
 
-        if not self.yolo_mode and tool_name not in self._auto_approved_tools:
+        if (
+            not self.message_handler.is_non_interactive
+            and not self.yolo_mode
+            and tool_name not in self._auto_approved_tools
+        ):
             # Request confirmation from the user
             confirmation = await self._wait_for_tool_confirmation(tool_use)
             action = confirmation.get("action", "deny")
@@ -82,7 +86,7 @@ class ToolManager:
                         "tool_use": tool_use,
                         "tool_result": (
                             "This tool call has been rejected by user, "
-                            "Immediately Stop and ask for reason why this call has been rejected, adapt the behavior if needed. "
+                            "Immediately stop current task and ask user the reason why this call has been rejected, adapt the behavior if needed. "
                             "Suggest alternative actions if possible."
                         ),
                         "is_error": True,
