@@ -1,4 +1,5 @@
 import os
+import fnmatch
 import subprocess
 from typing import Any, Dict, List, Optional
 from tree_sitter_language_pack import get_parser
@@ -856,7 +857,9 @@ class CodeAnalysisService:
 
         return count
 
-    def analyze_code_structure(self, path: str) -> Dict[str, Any] | str:
+    def analyze_code_structure(
+        self, path: str, exclude_patterns: List[str] = []
+    ) -> Dict[str, Any] | str:
         """
         Build a tree-sitter based structural map of source code files in a git repository.
 
@@ -871,14 +874,11 @@ class CodeAnalysisService:
             if not os.path.exists(path):
                 return {"error": f"Path does not exist: {path}"}
 
-            # Get the absolute path
-            abs_path = os.path.abspath(path)
-
             # Run git ls-files to get all tracked files
             try:
                 result = subprocess.run(
                     ["git", "ls-files"],
-                    cwd=abs_path,
+                    cwd=path,
                     capture_output=True,
                     text=True,
                     check=True,
@@ -886,26 +886,28 @@ class CodeAnalysisService:
                 files = result.stdout.strip().split("\n")
             except subprocess.CalledProcessError:
                 return {
-                    "error": f"Failed to run git ls-files on {abs_path}. Make sure it's a git repository."
+                    "error": f"Failed to run git ls-files on {path}. Make sure it's a git repository."
                 }
 
             # Filter for supported file types
             supported_files = []
             for file_path in files:
+                excluded = False
                 if file_path.strip():  # Skip empty lines
+                    # Check against glob exclude patterns
+                    for pattern in exclude_patterns:
+                        if fnmatch.fnmatch(file_path, pattern):
+                            excluded = True
+                            break
                     ext = os.path.splitext(file_path)[1].lower()
-                    if ext in self.LANGUAGE_MAP:
-                        supported_files.append(os.path.join(abs_path, file_path))
+                    if ext in self.LANGUAGE_MAP and not excluded:
+                        supported_files.append(os.path.join(path, file_path))
 
             # Analyze each file
             analysis_results = []
             errors = []
             for file_path in supported_files:
-                # Skip empty paths (can happen if git ls-files returns empty lines)
-                if not file_path:
-                    continue
-
-                rel_path = os.path.join(path, os.path.relpath(file_path, abs_path))
+                rel_path = os.path.relpath(file_path, path)
                 try:
                     language = self._detect_language(file_path)
 
@@ -932,7 +934,7 @@ class CodeAnalysisService:
                     errors.append({"path": rel_path, "error": str(e)})
 
             if not analysis_results:
-                return "Analysis completed but no valid results"
+                return "Analysis completed but no valid results. This may due to excluded patterns is not correct"
             return self._format_analysis_results(
                 analysis_results, supported_files, errors
             )
@@ -1043,6 +1045,9 @@ class CodeAnalysisService:
                 else:
                     node_info = node_name
 
+            if len(node_info) > 500:
+                node_info = node_info[:497] + "(REDACTED due to long content)..."
+
             lines.append(f"{prefix}{branch}{node_info}")
 
             # Process children
