@@ -169,6 +169,10 @@ class ChatCompleter(Completer):
                 "/jump",
                 "Jump to a previous conversation turn (usage: /jump <turn_number>)",
             ),
+            (
+                "/voice",
+                "Start with voice input",
+            ),
             ("/agent", "Switch agent or list available agents (usage: /agent [name])"),
             ("/model", "Switch model or list available models (usage: /model [id])"),
             (
@@ -180,6 +184,7 @@ class ChatCompleter(Completer):
             ("/list", "List available conversations"),
             ("/load", "Load a conversation (usage: /load <conversation_id>)"),
             ("/help", "Show help message"),
+            ("/toggle_transfer", "Toggle agent transfer enforcement on/off"),
             ("/exit", "Exit the application"),
             ("/quit", "Exit the application"),
         ]
