@@ -36,7 +36,6 @@ class GroqService(BaseLLMService):
         self.current_input_tokens = 0
         self.current_output_tokens = 0
         self.system_prompt = ""
-        self.temperature = 0.4
         logger.info("Initialized Groq Service")
 
     def set_think(self, budget_tokens) -> bool:
@@ -191,7 +190,7 @@ class GroqService(BaseLLMService):
             dict: Result of the tool execution
         """
         if tool_name not in self.tool_handlers:
-            return {"error": f"Tool '{tool_name}' not found"}
+            raise ValueError(f"Tool '{tool_name}' not found")
 
         handler = self.tool_handlers[tool_name]
         result = handler(**tool_params)
