@@ -12,8 +12,6 @@ class MessageEventHandler:
         if isinstance(chat_window, ChatWindow):
             self.chat_window = chat_window
         self.chat_window.thinking_content = ""
-        self.chunk_buffer_queue = []
-        self.think_buffer_queue = []
 
     def handle_event(self, event: str, data: Any):
         """Handle a message-related event."""
@@ -34,8 +32,7 @@ class MessageEventHandler:
 
     def handle_response_chunk(self, data):
         """Handle response chunks with smooth streaming."""
-        chunk_text, full_response = data
-        self.chunk_buffer_queue.extend(list(chunk_text))
+        _, full_response = data
 
         if full_response.strip():
             # Create bubble immediately if needed
@@ -49,8 +46,8 @@ class MessageEventHandler:
 
         # Use the individual chunk for smooth streaming
         if self.chat_window.current_response_bubble:
-            self.chat_window.current_response_bubble.add_streaming_chunk(
-                self.chunk_buffer_queue
+            self.chat_window.current_response_bubble.update_streaming_text(
+                full_response
             )
 
     def handle_user_message_created(self, data):
@@ -66,7 +63,6 @@ class MessageEventHandler:
 
     def handle_response_completed(self, data):
         """Handle response completion."""
-        self.chunk_buffer_queue = []
         if self.chat_window.current_response_bubble:
             # Finalize streaming and ensure full content is rendered
             self.chat_window.current_response_bubble.raw_text_buffer = data
@@ -80,7 +76,6 @@ class MessageEventHandler:
 
     def handle_thinking_started(self, data):
         """Handle thinking process started."""
-        self.think_buffer_queue = []
         agent_name = data
         self.chat_window.chat_components.add_system_message(
             f"💭 {agent_name.upper()}'s thinking process started"
@@ -94,12 +89,11 @@ class MessageEventHandler:
 
     def handle_thinking_chunk(self, chunk):
         """Handle a chunk of the thinking process."""
-        self.think_buffer_queue.extend(list(chunk))
         self.chat_window.thinking_content += chunk
         # Use smooth streaming for thinking chunks too
         if self.chat_window.current_thinking_bubble:
-            self.chat_window.current_thinking_bubble.add_streaming_chunk(
-                self.think_buffer_queue
+            self.chat_window.current_thinking_bubble.update_streaming_text(
+                self.chat_window.thinking_content
             )
 
     def handle_thinking_completed(self):
@@ -112,7 +106,6 @@ class MessageEventHandler:
             )
             self.chat_window.current_thinking_bubble._finalize_streaming()
         # Reset thinking bubble reference
-        self.think_buffer_queue = []
         self.chat_window.current_thinking_bubble = None
         self.chat_window.thinking_content = ""
 
