@@ -358,14 +358,44 @@ _GITHUB_COPILOT_MODELS = [
         name="GPT 4.1",
         description="",
         capabilities=["tool_use", "vision", "stream"],
-        default=True,
+        default=False,
+        input_token_price_1m=0.0,
+        output_token_price_1m=0.0,
+    ),
+    Model(
+        id="grok-code-fast-1",
+        provider="github_copilot",
+        name="Grok Code Fast 1",
+        description="",
+        capabilities=["tool_use", "vision", "stream"],
+        default=False,
+        input_token_price_1m=0.0,
+        output_token_price_1m=0.0,
+    ),
+    Model(
+        id="gpt-4o",
+        provider="github_copilot",
+        name="GPT 4o",
+        description="",
+        capabilities=["tool_use", "vision", "stream"],
+        default=False,
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
     Model(
         id="gpt-5",
         provider="github_copilot",
-        name="GPT 5 (Preview)",
+        name="GPT 5",
+        description="",
+        capabilities=["tool_use", "vision", "stream"],
+        default=False,
+        input_token_price_1m=0.0,
+        output_token_price_1m=0.0,
+    ),
+    Model(
+        id="gpt-5-mini",
+        provider="github_copilot",
+        name="GPT 5 mini",
         description="",
         capabilities=["tool_use", "vision", "stream", "thinking"],
         default=True,
