@@ -148,8 +148,8 @@ class MCPService:
             if agent_name:
                 agent_manager = AgentManager.get_instance()
                 agent = agent_manager.get_local_agent(agent_name)
-                if agent:
-                    agent.is_tool_ready = True
+                if agent and combined_server_id in agent.mcps_loading:
+                    agent.mcps_loading.remove(combined_server_id)
         finally:
             logger.info(f"MCPService: Cleaning up connection for {server_name}.")
             self.sessions.pop(server_name, None)
@@ -182,7 +182,7 @@ class MCPService:
             agent_manager = AgentManager.get_instance()
             agent = agent_manager.get_local_agent(agent_name)
             if agent:
-                agent.is_tool_ready = False
+                agent.mcps_loading.append(combined_server_id)
         logger.info(
             f"MCPService: Creating task for _manage_single_connection for {combined_server_id}"
         )
@@ -315,8 +315,11 @@ class MCPService:
                     registry.register_tool(
                         tool_definition_factory(), handler_factory, self
                     )
-            if isinstance(registry, LocalAgent):
-                registry.is_tool_ready = True
+            if (
+                isinstance(registry, LocalAgent)
+                and combined_server_id in registry.mcps_loading
+            ):
+                registry.mcps_loading.remove(combined_server_id)
 
         except Exception:
             logger.exception(
@@ -378,44 +381,35 @@ class MCPService:
         # Create namespaced tool name
         namespaced_name = f"{server_id}_{tool.name}"
 
+        from jsonref import replace_refs
+        import json
+
+        merged_inputSchema_string = json.dumps(
+            replace_refs(
+                tool.inputSchema,
+                merge_props=True,
+                jsonschema=True,
+            ),
+            indent=2,
+        )
+        merged_inputSchema = json.loads(merged_inputSchema_string)
+        if "$defs" in merged_inputSchema:
+            del merged_inputSchema["$defs"]
+
         # Format for different providers
         if provider == "claude":
             return {
                 "name": namespaced_name,
                 "description": tool.description,
-                "input_schema": tool.inputSchema,
+                "input_schema": merged_inputSchema,
             }
-        if provider == "github_copilot":
-            from jsonref import replace_refs
-            import json
-
-            merged_inputSchema_string = json.dumps(
-                replace_refs(
-                    tool.inputSchema,
-                    merge_props=True,
-                    jsonschema=True,
-                ),
-                indent=2,
-            )
-            merged_inputSchema = json.loads(merged_inputSchema_string)
-            if "$defs" in merged_inputSchema:
-                del merged_inputSchema["$defs"]
-            return {
-                "type": "function",
-                "function": {
-                    "name": namespaced_name,
-                    "description": tool.description,
-                    "parameters": merged_inputSchema,
-                },
-            }
-
         else:  # Default format (OpenAI-compatible)
             return {
                 "type": "function",
                 "function": {
                     "name": namespaced_name,
                     "description": tool.description,
-                    "parameters": tool.inputSchema,
+                    "parameters": merged_inputSchema,
                 },
             }
 
