@@ -1,6 +1,7 @@
 import os
 import chromadb
 import uuid
+from chromadb.config import Settings
 import numpy as np
 import queue
 import asyncio
@@ -8,6 +9,7 @@ from typing import List, Dict, Any, Optional
 from datetime import datetime, timedelta
 from threading import Thread, Event
 from AgentCrew.modules import logger
+import xmltodict
 
 from AgentCrew.modules.llm.base import BaseLLMService
 
@@ -16,7 +18,7 @@ from .voyageai_ef import VoyageEmbeddingFunction
 from AgentCrew.modules.prompts.constants import (
     SEMANTIC_EXTRACTING,
     PRE_ANALYZE_PROMPT,
-    POST_RETRIEVE_MEMORY,
+    # POST_RETRIEVE_MEMORY,
 )
 from .github_copilot_ef import GithubCopilotEmbeddingFunction
 import chromadb.utils.embedding_functions as embedding_functions
@@ -28,6 +30,7 @@ DEFAULT_QUEUE_TIMEOUT = 5.0  # seconds
 MAX_QUEUE_SIZE = 1000  # maximum pending operations
 WORKER_THREAD_NAME = "ChromaMemoryWorker"
 MEMORY_DB_PATH = "./memory_db"
+RELEVANT_THRESHOLD = 2
 
 
 class ChromaMemoryService(BaseMemoryService):
@@ -50,7 +53,9 @@ class ChromaMemoryService(BaseMemoryService):
         os.makedirs(os.path.dirname(self.db_path), exist_ok=True)
 
         # Initialize ChromaDB client with persistence
-        self.client = chromadb.PersistentClient(path=self.db_path)
+        self.client = chromadb.PersistentClient(
+            path=self.db_path, settings=Settings(anonymized_telemetry=False)
+        )
 
         self.llm_service = llm_service
         ## set to groq if key available
@@ -98,6 +103,7 @@ class ChromaMemoryService(BaseMemoryService):
         self.current_embedding_context = None
 
         self.context_embedding = []
+        self.current_conversation_context: Dict[str, Any] = {}
 
         # Memory queue infrastructure
         self._conversation_queue = queue.Queue(maxsize=MAX_QUEUE_SIZE)
@@ -134,6 +140,7 @@ class ChromaMemoryService(BaseMemoryService):
 
     def _memory_worker_thread(self):
         """Worker thread for processing conversation storage operations."""
+        loop = asyncio.new_event_loop()
         while not self._memory_stop_event.is_set():
             try:
                 # Get operation from queue with timeout
@@ -145,13 +152,16 @@ class ChromaMemoryService(BaseMemoryService):
                     break
 
                 # Process conversation storage
-                self._store_conversation_internal(operation_data)
+                loop.run_until_complete(
+                    self._store_conversation_internal(operation_data)
+                )
                 self._conversation_queue.task_done()
 
             except queue.Empty:
                 continue
             except Exception as e:
                 logger.error(f"Memory worker error: {e}")
+        loop.close()
 
     def _start_memory_worker(self):
         """Start the memory worker thread."""
@@ -172,7 +182,7 @@ class ChromaMemoryService(BaseMemoryService):
             except queue.Full:
                 logger.warning("Could not send shutdown signal to memory worker")
 
-    async def store_conversation(
+    def store_conversation(
         self, user_message: str, assistant_response: str, agent_name: str = "None"
     ) -> List[str]:
         """
@@ -206,7 +216,7 @@ class ChromaMemoryService(BaseMemoryService):
             logger.warning("Memory queue full, dropping conversation storage")
             return []
 
-    def _store_conversation_internal(self, operation_data: Dict[str, Any]):
+    async def _store_conversation_internal(self, operation_data: Dict[str, Any]):
         """Internal method to actually store conversation (runs in worker thread)."""
         try:
             user_message = operation_data["user_message"]
@@ -216,35 +226,67 @@ class ChromaMemoryService(BaseMemoryService):
 
             # Use the existing storage logic but make it synchronous
             ids = []
+            memory_data = {}
+            avaialble_ids = self.collection.get(
+                where={
+                    "agent": agent_name,
+                },
+                include=[],
+            )["ids"]
             if self.llm_service:
                 try:
                     # Process with LLM using asyncio.run to handle async call in worker thread
-                    conversation_text = asyncio.run(
-                        self.llm_service.process_message(
-                            PRE_ANALYZE_PROMPT.replace(
-                                "{current_date}", datetime.today().strftime("%Y-%m-%d")
-                            )
-                            .replace("{user_message}", user_message)
-                            .replace("{assistant_response}", assistant_response)
+                    analyzed_text = await self.llm_service.process_message(
+                        PRE_ANALYZE_PROMPT.replace(
+                            "{current_date}", datetime.today().strftime("%Y-%m-%d")
                         )
+                        .replace(
+                            "{current_conversation_context}",
+                            self.current_conversation_context.get(session_id, ""),
+                        )
+                        .replace("{existing_ids}", ", ".join(avaialble_ids))
+                        .replace("{user_message}", user_message)
+                        .replace("{assistant_response}", assistant_response)
                     )
-                    lines = conversation_text.split("\n")
-                    for i, line in enumerate(lines):
-                        if line == "## ID:":
-                            ids.append(lines[i + 1])
+                    start_xml = analyzed_text.find("<MEMORY>")
+                    end_xml = analyzed_text.find("</MEMORY>")
+                    if start_xml != -1 and end_xml != -1:
+                        xml_content = analyzed_text[
+                            start_xml : end_xml + len("</MEMORY>")
+                        ]
+                        memory_data = xmltodict.parse(xml_content)
+                    if "MEMORY" in memory_data and "ID" in memory_data["MEMORY"]:
+                        ids.append(memory_data["MEMORY"]["ID"])
+                    memory_data["MEMORY"]["USER_REQUEST"] = user_message
+                    memory_data["MEMORY"]["ASSISTANT_RESPONSE"] = assistant_response
+
                 except Exception as e:
                     logger.warning(f"Error processing conversation with LLM: {e}")
                     # Fallback to simple concatenation if LLM fails
-                    conversation_text = f"Date: {datetime.today().strftime('%Y-%m-%d')}.\n\n User: {user_message}.\n\nAssistant: {assistant_response}"
+                    memory_data = {
+                        "MEMORY": {
+                            "DATE": datetime.today().strftime("%Y-%m-%d"),
+                            "USER_REQUEST": user_message,
+                            "ASSISTANT_RESPONSE": assistant_response,
+                        }
+                    }
             else:
                 # Create the memory document by combining user message and response
-                conversation_text = f"Date: {datetime.today().strftime('%Y-%m-%d')}.\n\n User: {user_message}.\n\nAssistant: {assistant_response}"
+                memory_data = {
+                    "MEMORY": {
+                        "DATE": datetime.today().strftime("%Y-%m-%d"),
+                        "USER_REQUEST": user_message,
+                        "ASSISTANT_RESPONSE": assistant_response,
+                    }
+                }
 
             # Store in ChromaDB (existing logic)
             memory_id = str(uuid.uuid4())
             timestamp = datetime.now().isoformat()
+            conversation_document = xmltodict.unparse(memory_data, pretty=True)
+            self.current_conversation_context[session_id] = conversation_document
 
-            conversation_embedding = self.embedding_function([conversation_text])
+            conversation_embedding = self.embedding_function([conversation_document])
             self.context_embedding.append(conversation_embedding)
             if len(self.context_embedding) > 5:
                 self.context_embedding.pop(0)
@@ -253,7 +295,7 @@ class ChromaMemoryService(BaseMemoryService):
             if ids:
                 self.collection.upsert(
                     ids=[ids[0]],
-                    documents=[conversation_text],
+                    documents=[conversation_document],
                     embeddings=conversation_embedding,
                     metadatas=[
                         {
@@ -262,14 +304,12 @@ class ChromaMemoryService(BaseMemoryService):
                             "session_id": session_id,
                             "agent": agent_name,
                             "type": "conversation",
-                            "user_message": user_message,
-                            "assistant_messsage": assistant_response,
                         }
                     ],
                 )
             else:
                 self.collection.add(
-                    documents=[conversation_text],
+                    documents=[conversation_document],
                     embeddings=conversation_embedding,
                     metadatas=[
                         {
@@ -278,8 +318,6 @@ class ChromaMemoryService(BaseMemoryService):
                             "session_id": session_id,
                             "agent": agent_name,
                             "type": "conversation",
-                            "user_message": user_message,
-                            "assistant_messsage": assistant_response,
                         }
                     ],
                     ids=[memory_id],
@@ -313,9 +351,7 @@ class ChromaMemoryService(BaseMemoryService):
         self.current_embedding_context = None
         self.context_embedding = []
 
-    async def generate_user_context(
-        self, user_input: str, agent_name: str = "None"
-    ) -> str:
+    def generate_user_context(self, user_input: str, agent_name: str = "None") -> str:
         """
         Generate context based on user input by retrieving relevant memories.
 
@@ -325,7 +361,7 @@ class ChromaMemoryService(BaseMemoryService):
         Returns:
             Formatted string containing relevant context from past conversations
         """
-        return await self.retrieve_memory(user_input, 3, agent_name=agent_name)
+        return self.retrieve_memory(user_input, 3, agent_name=agent_name)
 
     async def _semantic_extracting(self, input: str) -> str:
         if self.llm_service:
@@ -340,8 +376,8 @@ class ChromaMemoryService(BaseMemoryService):
         else:
             return input
 
-    async def retrieve_memory(
-        self, keywords: str, limit: int = 5, agent_name: str = "None"
+    def retrieve_memory(
+        self, keywords: str, limit: int = 5, agent_name: str = ""
     ) -> str:
         """
         Retrieve relevant memories based on keywords.
@@ -354,15 +390,21 @@ class ChromaMemoryService(BaseMemoryService):
             Formatted string of relevant memories
         """
 
+        and_conditions: List[Dict[str, Any]] = []
+
+        if self.session_id.strip():
+            and_conditions.append({"session_id": {"$ne": self.session_id}})
+        if agent_name.strip():
+            and_conditions.append({"agent": agent_name})
+
         results = self.collection.query(
             query_texts=[keywords],
             n_results=limit,
-            where={
-                "$and": [
-                    {"session_id": {"$ne": self.session_id}},
-                    {"agent": agent_name},
-                ]
-            },
+            where={"$and": and_conditions}
+            if len(and_conditions) >= 2
+            else and_conditions[0]
+            if and_conditions
+            else None,
         )
 
         if not results["documents"] or not results["documents"][0]:
@@ -378,8 +420,9 @@ class ChromaMemoryService(BaseMemoryService):
                 conversation_chunks[conv_id] = {
                     "chunks": [],
                     "timestamp": metadata.get("timestamp", "unknown"),
-                    "relevance": len(results["documents"][0])
-                    - i,  # Higher relevance for earlier results
+                    "relevance": results["distances"][0][i]
+                    if results["distances"]
+                    else 99,
                 }
             conversation_chunks[conv_id]["chunks"].append(
                 (metadata.get("chunk_index", 0), doc)
@@ -387,7 +430,7 @@ class ChromaMemoryService(BaseMemoryService):
 
         # Sort conversations by relevance
         sorted_conversations = sorted(
-            conversation_chunks.items(), key=lambda x: x[1]["relevance"], reverse=True
+            conversation_chunks.items(), key=lambda x: x[1]["relevance"]
         )
 
         # Format the output
@@ -396,7 +439,8 @@ class ChromaMemoryService(BaseMemoryService):
             # Sort chunks by index
             sorted_chunks = sorted(conv_data["chunks"], key=lambda x: x[0])
             conversation_text = "\n".join([chunk for _, chunk in sorted_chunks])
-
+            if conv_data["relevance"] > RELEVANT_THRESHOLD:
+                continue
             # Format timestamp
             timestamp = "Unknown time"
             if conv_data["timestamp"] != "unknown":
@@ -406,22 +450,24 @@ class ChromaMemoryService(BaseMemoryService):
                 except Exception:
                     timestamp = conv_data["timestamp"]
 
-            output.append(f"--- Memory from {timestamp} ---\n{conversation_text}\n---")
+            output.append(
+                f"--- Memory from {timestamp} (Distance point: {conv_data['relevance']}) ---\n{conversation_text}\n---"
+            )
 
         memories = "\n\n".join(output)
-        if self.llm_service:
-            try:
-                return await self.llm_service.process_message(
-                    POST_RETRIEVE_MEMORY.replace("{keywords}", keywords).replace(
-                        "{memory_list}", memories
-                    )
-                )
-            except Exception as e:
-                logger.warning(f"Error processing retrieved memories with LLM: {e}")
-                # Fallback to returning raw memories if LLM processing fails
-                return memories
-        else:
-            return memories
+        # if self.llm_service:
+        #     try:
+        #         return await self.llm_service.process_message(
+        #             POST_RETRIEVE_MEMORY.replace("{keywords}", keywords).replace(
+        #                 "{memory_list}", memories
+        #             )
+        #         )
+        #     except Exception as e:
+        #         logger.warning(f"Error processing retrieved memories with LLM: {e}")
+        #         # Fallback to returning raw memories if LLM processing fails
+        #         return memories
+        # else:
+        return memories
 
     def _cosine_similarity(self, vec_a, vec_b):
         """Calculate cosine similarity between vectors"""
@@ -536,6 +582,15 @@ class ChromaMemoryService(BaseMemoryService):
                 "count": 0,
             }
 
+    def forget_ids(self, ids: List[str], agent_name: str = "None") -> Dict[str, Any]:
+        self.collection.delete(ids=ids, where={"agent": agent_name})
+
+        return {
+            "success": True,
+            "message": f"Successfully removed {len(ids)} memory chunks from {agent_name}",
+            "count": len(ids),
+        }
+
     def get_queue_status(self) -> Dict[str, Any]:
         """Get current queue status for monitoring."""
         return {
