@@ -25,7 +25,6 @@ class OpenAIService(BaseLLMService):
         self.tool_handlers = {}  # Map tool names to handler functions
         self._provider_name = "openai"
         self.system_prompt = ""
-        self.temperature = 0.4
         self.reasoning_effort = None
         logger.info("Initialized OpenAI Service")
 
@@ -44,7 +43,7 @@ class OpenAIService(BaseLLMService):
         ):
             if budget_tokens == "0" or budget_tokens == "none":
                 self.reasoning_effort = None
-            elif budget_tokens not in ["low", "medium", "high"]:
+            elif budget_tokens not in ["minimal", "low", "medium", "high"]:
                 raise ValueError("budget_tokens must be low, medium or high")
 
             self.reasoning_effort = budget_tokens
@@ -170,7 +169,7 @@ class OpenAIService(BaseLLMService):
             dict: Result of the tool execution
         """
         if tool_name not in self.tool_handlers:
-            return {"error": f"Tool '{tool_name}' not found"}
+            raise ValueError(f"Tool '{tool_name}' not found")
 
         handler = self.tool_handlers[tool_name]
         result = handler(**tool_params)
